<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 * User preferences form
 *
 * @package PhpMyAdmin
 */
declare(strict_types=1);

namespace PhpMyAdmin\Config\Forms\Page;

/**
 * Class NaviForm
 * @package PhpMyAdmin\Config\Forms\Page
 */
class NaviForm extends \PhpMyAdmin\Config\Forms\User\NaviForm
{
}
